@@ -10,12 +10,12 @@ use strict;
 use warnings;
 use English qw/ -no_match_vars /;
 
-our $VERSION     = 0.005;
+our $VERSION     = 0.06;
 our @EXPORT_OK   = qw//;
 our %EXPORT_TAGS = ();
 
 sub node {
-    my ($self) = @_;
+    my ($self, $options) = @_;
     my $version;
     my $path;
 
@@ -46,7 +46,7 @@ App::PS1::Plugin::Node - Shows current version of node if using nave
 
 =head1 VERSION
 
-This documentation refers to App::PS1::Plugin::Node version 0.005.
+This documentation refers to App::PS1::Plugin::Node version 0.06.
 
 =head1 SYNOPSIS
 
